==> zio-aws-ec2_2.13-5.17.123.1-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayMulticastDomainResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayMulticastDomainResponse(
    transitGatewayMulticastDomain: Option[
      zio.aws.ec2.model.TransitGatewayMulticastDomain
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse = {
    import DeleteTransitGatewayMulticastDomainResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
      .builder()
      .optionallyWith(
        transitGatewayMulticastDomain.map(value => value.buildAwsValue())
      )(_.transitGatewayMulticastDomain)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse
      .wrap(buildAwsValue())
}
object DeleteTransitGatewayMulticastDomainResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse =
      zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse(
        transitGatewayMulticastDomain.map(value => value.asEditable)
      )
    def transitGatewayMulticastDomain
        : Option[zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly]
    def getTransitGatewayMulticastDomain: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayMulticastDomain",
      transitGatewayMulticastDomain
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ) extends zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly {
    override val transitGatewayMulticastDomain
        : Option[zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly] =
      scala
        .Option(impl.transitGatewayMulticastDomain())
        .map(value =>
          zio.aws.ec2.model.TransitGatewayMulticastDomain.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ): zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/DeleteTransitGatewayMulticastDomainResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteTransitGatewayMulticastDomainResponse(
    transitGatewayMulticastDomain: Optional[
      zio.aws.ec2.model.TransitGatewayMulticastDomain
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse = {
    import DeleteTransitGatewayMulticastDomainResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
      .builder()
      .optionallyWith(
        transitGatewayMulticastDomain.map(value => value.buildAwsValue())
      )(_.transitGatewayMulticastDomain)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly =
    zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse
      .wrap(buildAwsValue())
}
object DeleteTransitGatewayMulticastDomainResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse =
      zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse(
        transitGatewayMulticastDomain.map(value => value.asEditable)
      )
    def transitGatewayMulticastDomain
        : Optional[zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly]
    def getTransitGatewayMulticastDomain: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayMulticastDomain",
      transitGatewayMulticastDomain
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ) extends zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly {
    override val transitGatewayMulticastDomain
        : Optional[zio.aws.ec2.model.TransitGatewayMulticastDomain.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayMulticastDomain())
        .map(value =>
          zio.aws.ec2.model.TransitGatewayMulticastDomain.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteTransitGatewayMulticastDomainResponse
  ): zio.aws.ec2.model.DeleteTransitGatewayMulticastDomainResponse.ReadOnly =
    new Wrapper(impl)
}
